@@ -15,24 +15,24 @@
 #' added in the forecasting. This can be used to specify any a priori 
 #' known component to be added to the forecasted predictor.
 #' @param gc.order a specification of the ARIMA model: the three components 
-#' \eqn{(p, d, q)} are the AR order, the degree of differencing, and the MA order.
-#' The default is an ARIMA\eqn{(1, 1, 0)}.
+#' \eqn{(p, d, q)} are the AR order, the degree of differencing, and the MA 
+#' order. The default is an ARIMA\eqn{(1, 1, 0)}.
 #' @param gc.include.constant a logical value indicating if the ARIMA model
 #' should include a constant value. The default is \code{TRUE}. 
 #' @param jumpchoice option to select the jump-off rates, i.e. the rates 
-#' from the final year of observation, to use in projections of mortality rates. 
-#' \code{"fit"}(default) uses the fitted rates and \code{"actual"} uses the 
-#' actual rates from the final year.
+#' from the final year of observation, to use in projections of mortality 
+#' rates. \code{"fit"}(default) uses the fitted rates and \code{"actual"} 
+#' uses the actual rates from the final year.
 #' @param kt.lookback optional argument to specify the look-back window to use
 #'        in the estimation of the MRWD for period indexes. By default all the 
-#'        estimated values are used in estimating the MRWD. If \code{kt.lookback}
-#'        is provided then the last \code{kt.lookback} years of 
-#'        \eqn{\kappa_t^{(i)}, i = 1,..N,} are used.
+#'        estimated values are used in estimating the MRWD. If 
+#'        \code{kt.lookback} is provided then the last \code{kt.lookback} 
+#'        years of \eqn{\kappa_t^{(i)}, i = 1,..N,} are used.
 #' @param gc.lookback optional argument to specify the look-back window to use
-#'        in the estimation of the ARIMA model for the cohort effect. By default all the 
-#'        estimated values are used in estimating the ARIMA model. If \code{gc.lookback}
-#'        is provided then the last \code{gc.lookback} years of 
-#'        \eqn{\gamma_{t-x}} are used.
+#'        in the estimation of the ARIMA model for the cohort effect. By 
+#'        default all the estimated values are used in estimating the ARIMA 
+#'        model. If \code{gc.lookback} is provided then the last 
+#'        \code{gc.lookback} years of \eqn{\gamma_{t-x}} are used.
 #' @param ... other arguments.
 #'  
 #' @return A list of class \code{"forStMoMo"} with components:
@@ -42,19 +42,20 @@
 #' \item{years}{vector of years for which a forecast has been produced. This
 #'  corresponds to the columns of \code{rates}.}
 #'  
-#' \item{kt.f}{ forecasts of period indexes of the model. This is a list with the 
-#'  \code{model} fitted to \eqn{\kappa_t}; the \code{mean}(central) forecast,
-#'  the \code{lower} and \code{upper} limits of the prediction interval; 
-#'  the confidence \code{level} associated with the prediction interval; and the 
-#'  \code{years} for which a forecast was produced. If the model does 
-#'   not have any age-period terms (i.e. \eqn{N=0}) this is set to \code{NULL}.}
+#' \item{kt.f}{ forecasts of period indexes of the model. This is a list with 
+#' the \code{model} fitted to \eqn{\kappa_t}; the \code{mean}(central) 
+#' forecast, the \code{lower} and \code{upper} limits of the prediction 
+#' interval; the confidence \code{level} associated with the prediction 
+#' interval; and the \code{years} for which a forecast was produced. If the 
+#' model does not have any age-period terms (i.e. \eqn{N=0}) this is set to 
+#' \code{NULL}.}
 #'   
-#' \item{gc.f}{ forecasts of cohort index of the model. This is a list with the 
-#'  \code{model} fitted to \eqn{\gamma_c}; the \code{mean}(point) forecast,
-#'  the \code{lower} and \code{upper} limits of the prediction interval; 
-#'  the confidence \code{level} associated with the prediction interval; and the 
-#'  \code{cohorts} for which a forecast was produced. If the mortality model does 
-#'  not have a cohort effect this is set to \code{NULL}.} 
+#' \item{gc.f}{ forecasts of cohort index of the model. This is a list with 
+#' the \code{model} fitted to \eqn{\gamma_c}; the \code{mean}(point) forecast,
+#' the \code{lower} and \code{upper} limits of the prediction interval; the
+#' confidence \code{level} associated with the prediction interval; and the 
+#' \code{cohorts} for which a forecast was produced. If the mortality model
+#' does not have a cohort effect this is set to \code{NULL}.} 
 #' 
 #' \item{oxt.f}{ the offset used in the forecast.}
 #' 
@@ -101,9 +102,10 @@
 #'               ages.fit = 55:89, wxt = wxt)
 #' APCfor1 <- forecast(APCfit)
 #' plot(APCfor1, parametricbx = FALSE, nCol = 3)
-#' APCfor2 <- forecast(APCfit, gc.order = c(0,2,2))
+#' APCfor2 <- forecast(APCfit, gc.order = c(0, 2, 2))
 #' plot(APCfor2, only.gc = TRUE)
-#' plot(c(APCfit$years, APCfor1$years) , (cbind(APCfor1$fitted, APCfor1$rates))["65", ], 
+#' plot(c(APCfit$years, APCfor1$years), 
+#'      cbind(APCfor1$fitted, APCfor1$rates)["65", ], 
 #'      type = "l", xlab = "year", ylab = "Mortality rate at age 65", 
 #'      main = "Forecasts with different models for gc")
 #' lines(APCfor2$years, APCfor2$rates["65", ], col = "blue")
@@ -134,10 +136,11 @@
 #'        lty = 1:3, col = c("black", "blue", "red"))
 #' @export
 forecast.fitStMoMo <-function(object, h = 50, level = 95, oxt = NULL,
-                              gc.order = c(1, 1, 0), gc.include.constant = TRUE,
+                              gc.order = c(1, 1, 0),
+                              gc.include.constant = TRUE,
                               jumpchoice = c("fit", "actual"), 
                               kt.lookback = NULL, gc.lookback = NULL,
-                              ...){
+                              ...) {
   
   jumpchoice <- match.arg(jumpchoice)
   level <- level[1]
@@ -150,7 +153,7 @@ forecast.fitStMoMo <-function(object, h = 50, level = 95, oxt = NULL,
   years <- object$years
   nYears <- length(years)
   if (is.null(kt.lookback)) kt.lookback <- nYears 
-  if(kt.lookback<=0)
+  if (kt.lookback <= 0)
     stop("kt.lookback must be positive")
   kt.lookback <- min(c(kt.lookback, nYears))
   yearsFor <- (years[nYears] + 1):(years[nYears] + h)
@@ -161,15 +164,15 @@ forecast.fitStMoMo <-function(object, h = 50, level = 95, oxt = NULL,
   kt.model <- NULL
   years.h <- years
   years.f <- yearsFor
-  if(object$model$N > 0){
+  if (object$model$N > 0) {
     kt.nNA <- max(which(!is.na(kt[1, ])))
     kt.hNA <- nYears - kt.nNA
-    kt.model <- mrwd(kt[, (1+nYears-kt.lookback):kt.nNA]) 
+    kt.model <- mrwd(kt[, (1 + nYears - kt.lookback):kt.nNA]) 
     kt.for <- forecast(kt.model, h = h + kt.hNA, level = level)
-    if(kt.hNA > 0) {
+    if (kt.hNA > 0) {
       years.h <- years[-((kt.nNA+1):nYears)]
       years.f <- c(years[(kt.nNA+1):nYears], years.f)
-      kt.h <-array(kt.h[,1:kt.nNA], c(nrow(kt),kt.nNA))
+      kt.h <-array(kt.h[, 1:kt.nNA], c(nrow(kt), kt.nNA))
       dimnames(kt.h)[[2]] <- years.h      
     }
     kt.lower <- kt.upper <- kt.for$mean
@@ -183,7 +186,7 @@ forecast.fitStMoMo <-function(object, h = 50, level = 95, oxt = NULL,
   cohorts <- object$cohorts
   nCohorts <- length(cohorts)
   if (is.null(gc.lookback)) gc.lookback <- nCohorts 
-  if(gc.lookback<=0)
+  if (gc.lookback <= 0)
     stop("gc.lookback must be positive")
   gc.lookback <- min(c(gc.lookback, nCohorts))
   gc.h <- gc
@@ -191,48 +194,49 @@ forecast.fitStMoMo <-function(object, h = 50, level = 95, oxt = NULL,
   gc.model <- NULL
   gc.f <- NULL
   cohorts.f <- (cohorts[nCohorts] + 1):(cohorts[nCohorts] + h)
-  if(!is.null(object$model$cohortAgeFun)){
+  if (!is.null(object$model$cohortAgeFun)) {
     gc.nNA <- max(which(!is.na(gc)))
     gc.hNA <- nCohorts - gc.nNA
-    gc.model <- forecast::Arima(gc[(1+nCohorts - gc.lookback):gc.nNA], order = gc.order, 
+    gc.model <- forecast::Arima(gc[(1 + nCohorts - gc.lookback):gc.nNA], 
+                                order = gc.order, 
                                 include.constant = gc.include.constant) 
     gc.for <- forecast(gc.model, h = h + gc.hNA, level = level) 
     
-  if(gc.hNA > 0){      
+  if (gc.hNA > 0) {      
       gc.h <- gc[-((gc.nNA+1):nCohorts)]
-      cohorts.h <- cohorts[-((gc.nNA+1):nCohorts)]
-      cohorts.f <- c(cohorts[(gc.nNA+1):nCohorts], cohorts.f)
+      cohorts.h <- cohorts[-((gc.nNA + 1):nCohorts)]
+      cohorts.f <- c(cohorts[(gc.nNA + 1):nCohorts], cohorts.f)
     }   
-    gc.f <- list(mean = as.vector(gc.for$mean), lower = as.vector(gc.for$lower), 
-                 upper = as.vector(gc.for$upper), level = level,
+    gc.f <- list(mean = as.vector(gc.for$mean), 
+                 lower = as.vector(gc.for$lower), 
+                 upper = as.vector(gc.for$upper), level = level, 
                  model = gc.model, cohorts = cohorts.f)
     
     names(gc.f$mean) <- names(gc.f$upper) <- names(gc.f$lower) <- cohorts.f
   }  
   #Offset
-  if(is.null(oxt)) oxt <- 0
+  if (is.null(oxt)) oxt <- 0
   oxt.f <- matrix(oxt, nrow = nAges, ncol = h)
   colnames(oxt.f) <- yearsFor
   rownames(oxt.f) <- agesFor
   #predict rates
   rates <- predict(object, years = c(years.h, years.f), 
-                   kt = cbind(kt.h,kt.f$mean), gc = c(gc.h, gc.f$mean),
-                  oxt = cbind(object$oxt,oxt.f), type = "rates")
+                   kt = cbind(kt.h, kt.f$mean), gc = c(gc.h, gc.f$mean),
+                   oxt = cbind(object$oxt, oxt.f), type = "rates")
   
   #Apply jump-off option
-  forcastRates <- rates[,(nYears+1):(nYears+h)]
-  fittedRates <- rates[,1:nYears]
+  forcastRates <- rates[, (nYears + 1):(nYears + h)]
+  fittedRates <- rates[, 1:nYears]
   if (jumpchoice == "actual") {
     jumpoffRates <- (object$Dxt / object$Ext)[, nYears]
     forcastRates <- forcastRates * jumpoffRates / fittedRates[ , nYears]
   }
   
   #prepare output
-  structure(list(rates = forcastRates, ages = agesFor, 
-                 years = yearsFor, kt.f = kt.f, gc.f = gc.f, oxt.f = oxt.f, 
+  structure(list(rates = forcastRates, ages = agesFor, years = yearsFor, 
+                 kt.f = kt.f, gc.f = gc.f, oxt.f = oxt.f, 
                  fitted = fittedRates, model = object,
-                 jumpchoice = jumpchoice,
-                 call = match.call()), 
+                 jumpchoice = jumpchoice, call = match.call()), 
             class = "forStMoMo")
 }
 
@@ -254,6 +258,3 @@ print.forStMoMo <- function(x,...) {
   cat(paste("\nYears in forecast:", min(x$years), "-", max(x$years)))
   cat(paste("\nAges in forecast:", min(x$ages), "-", max(x$ages), "\n"))  
 }
-
-
-
